import { json, ValidationError, withServiceKeys, } from "@typespec/spec-api";
export const Scenarios = {};
function pageableHandler(req) {
    req.expect.containsQueryParam("maxpagesize", "3");
    const skipToken = req.query["skipToken"];
    if (skipToken === undefined) {
        return {
            pass: "firstPage",
            status: 200,
            body: json({
                value: [{ name: "user5" }, { name: "user6" }, { name: "user7" }],
                nextLink: `${req.baseUrl}/payload/pageable?skipToken=name-user7&maxpagesize=3`,
            }),
        };
    }
    else if (skipToken === "name-user7") {
        return {
            pass: "secondPage",
            status: 200,
            body: json({ value: [{ name: "user8" }] }),
        };
    }
    else {
        throw new ValidationError("Unsupported skipToken query parameter", `Not provided for first page, "name-user7" for second page`, req.query["skipToken"]);
    }
}
Scenarios.Payload_Pageable_list = withServiceKeys(["firstPage", "secondPage"]).pass([
    {
        uri: "/payload/pageable",
        method: "get",
        request: {
            params: {
                maxpagesize: "3",
            },
        },
        response: {
            status: 200,
            body: json({
                value: [{ name: "user5" }, { name: "user6" }, { name: "user7" }],
                nextLink: `/payload/pageable?skipToken=name-user7&maxpagesize=3`,
            }),
        },
        handler: pageableHandler,
        kind: "MockApiDefinition",
    },
    {
        uri: "/payload/pageable",
        method: "get",
        request: {
            params: {
                maxpagesize: "3",
                skipToken: "name-user7",
            },
        },
        response: {
            status: 200,
            body: json({ value: [{ name: "user8" }] }),
        },
        handler: pageableHandler,
        kind: "MockApiDefinition",
    },
]);
//# sourceMappingURL=mockapi.js.map